@@ -234,44 +234,19 @@ class Database(DatabaseInterface):
             if module in ('ir', 'res'):
                 state = 'to install'
             info = get_module_info(module)
-            cursor.execute('INSERT INTO ir_module_module '
+            cursor.execute('INSERT INTO ir_module '
                 '(create_uid, create_date, name, state) '
                 'VALUES (%s, now(), %s, %s)',
                 (0, module, state))
             cursor.execute('SELECT LAST_INSERT_ID()')
             module_id, = cursor.fetchone()
             for dependency in info.get('depends', []):
-                cursor.execute('INSERT INTO ir_module_module_dependency '
+                cursor.execute('INSERT INTO ir_module_dependency '
                     '(create_uid, create_date, module, name) '
                     'VALUES (%s, now(), %s, %s)',
                     (0, module_id, dependency))
 
 
-class _Cursor(MySQLdb.cursors.Cursor):
-
-    def __build_dict(self, row):
-        return dict((desc[0], row[i])
-                for i, desc in enumerate(self.description))
-
-    def dictfetchone(self):
-        row = self.fetchone()
-        if row:
-            return self.__build_dict(row)
-        else:
-            return row
-
-    def dictfetchmany(self, size):
-        rows = self.fetchmany(size)
-        return [self.__build_dict(row) for row in rows]
-
-    def dictfetchall(self):
-        rows = self.fetchall()
-        return [self.__build_dict(row) for row in rows]
-
-    def fetchall(self):
-        return list(super(_Cursor, self).fetchall())
-
-
 class Cursor(CursorInterface):
 
     def __init__(self, conn, database_name):
@@ -279,7 +254,7 @@ class Cursor(CursorInterface):
         self._conn = conn
         self.database_name = database_name
         self.dbname = self.database_name  # XXX to remove
-        self.cursor = conn.cursor(_Cursor)
+        self.cursor = conn.cursor()
 
     def __getattr__(self, name):
         return getattr(self.cursor, name)
@@ -312,8 +287,8 @@ class Cursor(CursorInterface):
                     'ir_ui_menu',
                     'res_user',
                     'res_group',
-                    'ir_module_module',
-                    'ir_module_module_dependency',
+                    'ir_module',
+                    'ir_module_dependency',
                     'ir_translation',
                     'ir_lang',
                     ):
@@ -333,6 +308,9 @@ class Cursor(CursorInterface):
     def has_constraint(self):
         return False
 
+    def has_multirow_insert(self):
+        return True
+
     def limit_clause(self, select, limit=None, offset=None):
         if offset and limit is None:
             limit = 18446744073709551610  # max bigint
