@@ -21,8 +21,8 @@ except ImportError:
     from sqlite3 import IntegrityError as DatabaseIntegrityError
     from sqlite3 import OperationalError as DatabaseOperationalError
 from sql import Flavor, Table
-from sql.functions import (Function, Extract, Position, Now, Substring,
-    Overlay, CharLength)
+from sql.functions import (Function, Extract, Position, Substring,
+    Overlay, CharLength, CurrentTimestamp)
 
 __all__ = ['Database', 'DatabaseIntegrityError', 'DatabaseOperationalError',
     'Cursor']
@@ -138,6 +138,11 @@ class SQLiteCharLength(Function):
     _function = 'LENGTH'
 
 
+class SQLiteCurrentTimestamp(Function):
+    __slots__ = ()
+    _function = 'NOW'  # More precise
+
+
 def sign(value):
     if value > 0:
         return 1
@@ -153,6 +158,7 @@ MAPPING = {
     Substring: SQLiteSubstring,
     Overlay: SQLiteOverlay,
     CharLength: SQLiteCharLength,
+    CurrentTimestamp: SQLiteCurrentTimestamp,
     }
 
 
@@ -297,8 +303,8 @@ class Database(DatabaseInterface):
                 if (len(line) > 0) and (not line.isspace()):
                     cursor.execute(line)
 
-        ir_module = Table('ir_module_module')
-        ir_module_dependency = Table('ir_module_module_dependency')
+        ir_module = Table('ir_module')
+        ir_module_dependency = Table('ir_module_dependency')
         for module in ('ir', 'res', 'webdav'):
             state = 'uninstalled'
             if module in ('ir', 'res'):
@@ -307,7 +313,7 @@ class Database(DatabaseInterface):
             insert = ir_module.insert(
                 [ir_module.create_uid, ir_module.create_date, ir_module.name,
                     ir_module.state],
-                [[0, Now(), module, state]])
+                [[0, CurrentTimestamp(), module, state]])
             cursor.execute(*insert)
             cursor.execute('SELECT last_insert_rowid()')
             module_id, = cursor.fetchone()
@@ -317,32 +323,10 @@ class Database(DatabaseInterface):
                         ir_module_dependency.create_date,
                         ir_module_dependency.module, ir_module_dependency.name
                         ],
-                    [[0, Now(), module_id, dependency]])
+                    [[0, CurrentTimestamp(), module_id, dependency]])
                 cursor.execute(*insert)
 
 
-class _Cursor(sqlite.Cursor):
-
-    def __build_dict(self, row):
-        return dict((desc[0], row[i])
-                for i, desc in enumerate(self.description))
-
-    def dictfetchone(self):
-        row = self.fetchone()
-        if row:
-            return self.__build_dict(row)
-        else:
-            return row
-
-    def dictfetchmany(self, size):
-        rows = self.fetchmany(size)
-        return [self.__build_dict(row) for row in rows]
-
-    def dictfetchall(self):
-        rows = self.fetchall()
-        return [self.__build_dict(row) for row in rows]
-
-
 class Cursor(CursorInterface):
     IN_MAX = 200
 
@@ -351,7 +335,7 @@ class Cursor(CursorInterface):
         self._conn = conn
         self.database_name = database_name
         self.dbname = self.database_name  # XXX to remove
-        self.cursor = conn.cursor(_Cursor)
+        self.cursor = conn.cursor()
 
     def __getattr__(self, name):
         if _FIX_ROWCOUNT and name == 'rowcount':
@@ -387,8 +371,8 @@ class Cursor(CursorInterface):
                 'ir_ui_menu',
                 'res_user',
                 'res_group',
-                'ir_module_module',
-                'ir_module_module_dependency',
+                'ir_module',
+                'ir_module_dependency',
                 'ir_translation',
                 'ir_lang',
                 ])
@@ -408,6 +392,9 @@ class Cursor(CursorInterface):
     def has_constraint(self):
         return False
 
+    def has_multirow_insert(self):
+        return True
+
 sqlite.register_converter('NUMERIC', lambda val: Decimal(val.decode('utf-8')))
 if sys.version_info[0] == 2:
     sqlite.register_adapter(Decimal, lambda val: buffer(str(val)))
