@@ -12,7 +12,7 @@ try:
 except ImportError:
     import json
 
-from ..model import ModelView, ModelSQL, fields
+from ..model import ModelView, ModelSQL, fields, Unique
 from ..report import Report
 from ..wizard import Wizard, StateView, StateAction, Button
 from ..transaction import Transaction
@@ -64,8 +64,9 @@ class Model(ModelSQL, ModelView):
     @classmethod
     def __setup__(cls):
         super(Model, cls).__setup__()
+        table = cls.__table__()
         cls._sql_constraints += [
-            ('model_uniq', 'UNIQUE(model)',
+            ('model_uniq', Unique(table, table.model),
                 'The model must be unique!'),
             ]
         cls._error_messages.update({
@@ -249,8 +250,9 @@ class ModelField(ModelSQL, ModelView):
     @classmethod
     def __setup__(cls):
         super(ModelField, cls).__setup__()
+        table = cls.__table__()
         cls._sql_constraints += [
-            ('name_model_uniq', 'UNIQUE(name, model)',
+            ('name_model_uniq', Unique(table, table.name, table.model),
                 'The field name in model must be unique!'),
             ]
         cls._error_messages.update({
@@ -509,10 +511,10 @@ class ModelAccess(ModelSQL, ModelView):
                 condition=user_group.group == model_access.group
                 ).select(
                 ir_model.model,
-                Max(Case((model_access.perm_read, 1), else_=0)),
-                Max(Case((model_access.perm_write, 1), else_=0)),
-                Max(Case((model_access.perm_create, 1), else_=0)),
-                Max(Case((model_access.perm_delete, 1), else_=0)),
+                Max(Case((model_access.perm_read == True, 1), else_=0)),
+                Max(Case((model_access.perm_write == True, 1), else_=0)),
+                Max(Case((model_access.perm_create == True, 1), else_=0)),
+                Max(Case((model_access.perm_delete == True, 1), else_=0)),
                 where=ir_model.model.in_(models)
                 & ((user_group.user == user) | (model_access.group == Null)),
                 group_by=ir_model.model))
@@ -694,10 +696,10 @@ class ModelFieldAccess(ModelSQL, ModelView):
                 ).select(
                 ir_model.model,
                 model_field.name,
-                Max(Case((field_access.perm_read, 1), else_=0)),
-                Max(Case((field_access.perm_write, 1), else_=0)),
-                Max(Case((field_access.perm_create, 1), else_=0)),
-                Max(Case((field_access.perm_delete, 1), else_=0)),
+                Max(Case((field_access.perm_read == True , 1), else_=0)),
+                Max(Case((field_access.perm_write == True, 1), else_=0)),
+                Max(Case((field_access.perm_create == True, 1), else_=0)),
+                Max(Case((field_access.perm_delete == True, 1), else_=0)),
                 where=ir_model.model.in_(models)
                 & ((user_group.user == user) | (field_access.group == Null)),
                 group_by=[ir_model.model, model_field.name]))
@@ -770,8 +772,9 @@ class ModelButton(ModelSQL, ModelView):
     @classmethod
     def __setup__(cls):
         super(ModelButton, cls).__setup__()
+        table = cls.__table__()
         cls._sql_constraints += [
-            ('name_model_uniq', 'UNIQUE(name, model)',
+            ('name_model_uniq', Unique(table, table.name, table.model),
                 'The button name in model must be unique!'),
             ]
         cls._order.insert(0, ('model', 'ASC'))
@@ -838,8 +841,10 @@ class ModelData(ModelSQL, ModelView):
     @classmethod
     def __setup__(cls):
         super(ModelData, cls).__setup__()
+        table = cls.__table__()
         cls._sql_constraints = [
-            ('fs_id_module_model_uniq', 'UNIQUE("fs_id", "module", "model")',
+            ('fs_id_module_model_uniq',
+                Unique(table, table.fs_id, table.module, table.model),
                 'The triple (fs_id, module, model) must be unique!'),
         ]
         cls._buttons.update({
@@ -939,7 +944,7 @@ class ModelData(ModelSQL, ModelView):
             if values != fs_values:
                 record = Model(data.db_id)
                 Model.write([record], fs_values)
-                values.update(fs_values)
+                values = fs_values
             to_write.extend([[data], {
                         'values': cls.dump_values(values),
                         }])
