@@ -145,7 +145,7 @@ class Rule(ModelSQL, ModelView):
     def _get_context():
         User = Pool().get('res.user')
         user_id = Transaction().user
-        with Transaction().set_context(_check_access=False):
+        with Transaction().set_context(_check_access=False, _datetime=None):
             user = EvalEnvironment(User(user_id), User)
         return {
             'user': user,
