@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
-#This file is part of Tryton.  The COPYRIGHT file at the top level of')
-#this repository contains the full copyright notices and license terms.')
+# This file is part of Tryton.  The COPYRIGHT file at the top level of')
+# this repository contains the full copyright notices and license terms.')
 TIME_LOCALE = \
 {'bg_BG': {'%A': [u'\u043f\u043e\u043d\u0435\u0434\u0435\u043b\u043d\u0438\u043a',
                   u'\u0432\u0442\u043e\u0440\u043d\u0438\u043a',
@@ -305,7 +305,7 @@ TIME_LOCALE = \
                   u'oct',
                   u'nov',
                   u'dic'],
-           '%p': [u'AM', u'PM']},
+           '%p': [u'', u'']},
  'es_ES': {'%A': [u'lunes',
                   u'martes',
                   u'mi\xe9rcoles',
@@ -443,59 +443,65 @@ TIME_LOCALE = \
                   u'\u041e\u043a\u0442\u044f\u0431\u0440\u044c',
                   u'\u041d\u043e\u044f\u0431\u0440\u044c',
                   u'\u0414\u0435\u043a\u0430\u0431\u0440\u044c'],
-           '%a': [u'\u041f\u043d.',
-                  u'\u0412\u0442.',
-                  u'\u0421\u0440.',
-                  u'\u0427\u0442.',
-                  u'\u041f\u0442.',
-                  u'\u0421\u0431.',
-                  u'\u0412\u0441.'],
+           '%a': [u'\u041f\u043d',
+                  u'\u0412\u0442',
+                  u'\u0421\u0440',
+                  u'\u0427\u0442',
+                  u'\u041f\u0442',
+                  u'\u0421\u0431',
+                  u'\u0412\u0441'],
            '%b': [None,
-                  u'\u044f\u043d\u0432.',
-                  u'\u0444\u0435\u0432\u0440.',
-                  u'\u043c\u0430\u0440\u0442\u0430',
-                  u'\u0430\u043f\u0440.',
-                  u'\u043c\u0430\u044f',
-                  u'\u0438\u044e\u043d\u044f',
-                  u'\u0438\u044e\u043b\u044f',
-                  u'\u0430\u0432\u0433.',
-                  u'\u0441\u0435\u043d\u0442.',
-                  u'\u043e\u043a\u0442.',
-                  u'\u043d\u043e\u044f\u0431.',
-                  u'\u0434\u0435\u043a.'],
+                  u'\u044f\u043d\u0432',
+                  u'\u0444\u0435\u0432',
+                  u'\u043c\u0430\u0440',
+                  u'\u0430\u043f\u0440',
+                  u'\u043c\u0430\u0439',
+                  u'\u0438\u044e\u043d',
+                  u'\u0438\u044e\u043b',
+                  u'\u0430\u0432\u0433',
+                  u'\u0441\u0435\u043d',
+                  u'\u043e\u043a\u0442',
+                  u'\u043d\u043e\u044f',
+                  u'\u0434\u0435\u043a'],
            '%p': [u'', u'']},
-  'sl_SI': {'%A':  [u'ponedeljek',
-                    u'torek',
-                    u'sreda',
-                    u'\u010detrtek',
-                    u'petek',
-                    u'sobota',
-                    u'nedelja'],
-             '%B': [None,
-                    u'januar',
-                    u'februar',
-                    u'marec',
-                    u'april',
-                    u'maj',
-                    u'junij',
-                    u'julij',
-                    u'avgust',
-                    u'september',
-                    u'oktober',
-                    u'november',
-                    u'december'],
-             '%a': [u'pon', u'tor', u'sre', u'\u010det', u'pet', u'sob', u'ned'],
-             '%b': [None,
-                    u'jan',
-                    u'feb',
-                    u'mar',
-                    u'apr',
-                    u'maj',
-                    u'jun',
-                    u'jul',
-                    u'avg',
-                    u'sep',
-                    u'okt',
-                    u'nov',
-                    u'dec'],
-             '%p': [u'', u'']}}
+ 'sl_SI': {'%A': [u'ponedeljek',
+                  u'torek',
+                  u'sreda',
+                  u'\u010detrtek',
+                  u'petek',
+                  u'sobota',
+                  u'nedelja'],
+           '%B': [None,
+                  u'januar',
+                  u'februar',
+                  u'marec',
+                  u'april',
+                  u'maj',
+                  u'junij',
+                  u'julij',
+                  u'avgust',
+                  u'september',
+                  u'oktober',
+                  u'november',
+                  u'december'],
+           '%a': [u'pon',
+                  u'tor',
+                  u'sre',
+                  u'\u010det',
+                  u'pet',
+                  u'sob',
+                  u'ned'],
+           '%b': [None,
+                  u'jan',
+                  u'feb',
+                  u'mar',
+                  u'apr',
+                  u'maj',
+                  u'jun',
+                  u'jul',
+                  u'avg',
+                  u'sep',
+                  u'okt',
+                  u'nov',
+                  u'dec'],
+           '%p': [u'', u'']}}
