@@ -19,7 +19,7 @@ from sql.conditionals import Case
 from sql.operators import Or, And
 from sql.aggregate import Max
 
-from ..model import ModelView, ModelSQL, fields
+from ..model import ModelView, ModelSQL, fields, Unique
 from ..wizard import Wizard, StateView, StateTransition, StateAction, \
     Button
 from ..tools import file_open, reduce_ids, grouped_slice
@@ -80,9 +80,11 @@ class Translation(ModelSQL, ModelView):
     @classmethod
     def __setup__(cls):
         super(Translation, cls).__setup__()
+        t = cls.__table__()
         cls._sql_constraints += [
             ('translation_md5_uniq',
-                'UNIQUE (name, res_id, lang, type, src_md5, module)',
+                Unique(t,
+                    t.name, t.res_id, t.lang, t.type, t.src_md5, t.module),
                 'Translation must be unique'),
         ]
         cls._error_messages.update({
@@ -847,6 +849,8 @@ class Translation(ModelSQL, ModelView):
                 id2translation = dict((t.id, t)
                     for t in cls.browse(translation_ids))
             for entry in pofile:
+                if entry.obsolete:
+                    continue
                 translation, res_id = cls.from_poentry(entry)
                 translation.lang = lang
                 translation.module = module
@@ -1051,15 +1055,6 @@ class TranslationSet(Wizard):
                 document = xml.dom.minidom.parseString(style_xml)
                 strings += self._translate_report(document.documentElement)
 
-            if report.style_content:
-                style_io = StringIO.StringIO(report.style_content)
-                style_z = zipfile.ZipFile(style_io, mode='r')
-                style_xml = style_z.read('styles.xml')
-
-                document = xml.dom.minidom.parseString(style_xml)
-
-                strings += self._translate_report(document.documentElement)
-
             for string in {}.fromkeys(strings).keys():
                 src_md5 = Translation.get_src_md5(string)
                 done = False
@@ -1576,7 +1571,7 @@ class TranslationExportStart(ModelView):
             ('translatable', '=', True),
             ('code', '!=', 'en_US'),
             ])
-    module = fields.Many2One('ir.module.module', 'Module', required=True,
+    module = fields.Many2One('ir.module', 'Module', required=True,
         domain=[
             ('state', 'in', ['installed', 'to upgrade', 'to remove']),
             ])
