@@ -5,7 +5,7 @@ import time
 from sql import Literal, Null
 from sql.aggregate import Count, Max
 
-from ..model import ModelView, ModelSQL, fields, EvalEnvironment
+from ..model import ModelView, ModelSQL, fields, EvalEnvironment, Check
 from ..pyson import Eval, PYSONDecoder
 from ..tools import grouped_slice
 from .. import backend
@@ -40,7 +40,7 @@ class Trigger(ModelSQL, ModelView):
         'invisible': Eval('on_time', False),
         }, depends=['on_time'])
     condition = fields.Char('Condition', required=True,
-        help='A Python statement evaluated with record represented by '
+        help='A PYSON statement evaluated with record represented by '
         '"self"\nIt triggers the action if true.')
     limit_number = fields.Integer('Limit Number', required=True,
         help='Limit the number of call to "Action Function" by records.\n'
@@ -56,14 +56,18 @@ class Trigger(ModelSQL, ModelView):
     @classmethod
     def __setup__(cls):
         super(Trigger, cls).__setup__()
+        t = cls.__table__()
         cls._sql_constraints += [
             ('on_exclusive',
-                'CHECK(NOT(on_time AND (on_create OR on_write OR on_delete)))',
+                Check(t, ~((t.on_time == True)
+                        & ((t.on_create == True)
+                            | (t.on_write == True)
+                            | (t.on_delete == True)))),
                 '"On Time" and others are mutually exclusive!'),
             ]
         cls._error_messages.update({
                 'invalid_condition': ('Condition "%(condition)s" is not a '
-                    'valid python expression on trigger "%(trigger)s".'),
+                    'valid PYSON expression on trigger "%(trigger)s".'),
                 })
         cls._order.insert(0, ('name', 'ASC'))
 
@@ -102,8 +106,8 @@ class Trigger(ModelSQL, ModelView):
         '''
         for trigger in triggers:
             try:
-                compile(trigger.condition, '', 'eval')
-            except (SyntaxError, TypeError):
+                PYSONDecoder(noeval=True).decode(trigger.condition)
+            except Exception:
                 cls.raise_user_error('invalid_condition', {
                         'condition': trigger.condition,
                         'trigger': trigger.rec_name,
