@@ -3,6 +3,7 @@
 from itertools import groupby
 
 from sql import Null
+from sql.conditionals import Case
 
 from trytond.model import ModelView, ModelSQL, fields
 from trytond.transaction import Transaction
@@ -108,7 +109,7 @@ class UIMenu(ModelSQL, ModelView):
                 })
 
     @classmethod
-    def order_complet_name(cls, tables):
+    def order_complete_name(cls, tables):
         return cls.name.convert_order('name', tables, cls)
 
     @staticmethod
@@ -221,8 +222,6 @@ class UIMenu(ModelSQL, ModelView):
 
     @classmethod
     def set_action(cls, menus, name, value):
-        if not value:
-            return
         pool = Pool()
         ActionKeyword = pool.get('ir.action.keyword')
         action_keywords = []
@@ -236,11 +235,13 @@ class UIMenu(ModelSQL, ModelView):
         if action_keywords:
             with Transaction().set_context(_timestamp=False):
                 ActionKeyword.delete(action_keywords)
+        if not value:
+            return
         if isinstance(value, basestring):
             action_type, action_id = value.split(',')
         else:
             action_type, action_id = value
-        if not int(action_id):
+        if int(action_id) <= 0:
             return
         Action = pool.get(action_type)
         action = Action(int(action_id))
@@ -296,7 +297,7 @@ class UIMenuFavorite(ModelSQL, ModelView):
     @staticmethod
     def order_sequence(tables):
         table, _ = tables[None]
-        return [table.sequence == Null, table.sequence]
+        return [Case((table.sequence == Null, 0), else_=1), table.sequence]
 
     @staticmethod
     def default_user():
