@@ -1,5 +1,5 @@
-#This file is part of Tryton.  The COPYRIGHT file at the top level of
-#this repository contains the full copyright notices and license terms.
+# This file is part of Tryton.  The COPYRIGHT file at the top level of
+# this repository contains the full copyright notices and license terms.
 from sql import Query, Expression
 
 from .field import Field, SQLType
@@ -9,9 +9,10 @@ from ... import backend
 
 class Binary(Field):
     '''
-    Define a binary field (``str``).
+    Define a binary field (``bytes``).
     '''
     _type = 'binary'
+    cast = bytearray if bytes == str else bytes
 
     def __init__(self, string='', help='', required=False, readonly=False,
             domain=None, states=None, select=False, on_change=None,
@@ -28,10 +29,10 @@ class Binary(Field):
             select=select, on_change=on_change, on_change_with=on_change_with,
             depends=depends, context=context, loading=loading)
 
-    @staticmethod
-    def get(ids, model, name, values=None):
+    @classmethod
+    def get(cls, ids, model, name, values=None):
         '''
-        Convert the binary value into ``str``
+        Convert the binary value into ``bytes``
 
         :param ids: a list of ids
         :param model: a string with the name of the model
@@ -42,7 +43,7 @@ class Binary(Field):
         if values is None:
             values = {}
         res = {}
-        converter = buffer
+        converter = cls.cast
         default = None
         format_ = Transaction().context.pop('%s.%s' % (model.__name__, name),
             '')
@@ -50,7 +51,14 @@ class Binary(Field):
             converter = len
             default = 0
         for i in values:
-            res[i['id']] = converter(i[name]) if i[name] else default
+            value = i[name]
+            if value:
+                if isinstance(value, unicode):
+                    value = value.encode('utf-8')
+                value = converter(value)
+            else:
+                value = default
+            res[i['id']] = value
         for i in ids:
             res.setdefault(i, default)
         return res
