@@ -4,11 +4,12 @@ import copy
 
 from sql import Cast, Literal, Null
 from sql.functions import Substring, Position
-from sql.conditionals import Case
 
 from .function import Function
 from .field import Field, SQL_OPERATORS
 from .numeric import Numeric
+from .integer import Integer
+from .float import Float
 from ...transaction import Transaction
 from ...pool import Pool
 
@@ -76,7 +77,7 @@ class Property(Function):
 
         sql_type = self._field.sql_type().base
 
-        property_cond = Rule.domain_get('ir.property')
+        property_cond = Rule.query_get('ir.property')
 
         property_ = Property.__table__()
         model_field = Field.__table__()
@@ -96,9 +97,7 @@ class Property(Function):
                         Position(',', property_.res) + Literal(1)),
                     Model.id.sql_type().base),
                 property_.id,
-                where=Case((cond, self.get_condition(sql_type, domain,
-                            property_)),
-                    else_=False)))
+                where=cond & self.get_condition(sql_type, domain, property_)))
 
         props = cursor.fetchall()
         default = None
@@ -145,8 +144,12 @@ class Property(Function):
         operator = clause[1]
         value = clause[2]
 
-        numeric = Numeric('numeric')
-        if sql_type == numeric.sql_type().base and value:
+        sql_types = [
+            Numeric('numeric').sql_type().base,
+            Integer('integer').sql_type().base,
+            Float('float').sql_type().base,
+            ]
+        if sql_type in sql_types and value:
             if isinstance(value, (list, tuple)):
                 value = [Cast(v, sql_type) for v in value]
             else:
@@ -165,7 +168,7 @@ class Property(Function):
             return column.in_(value)
         elif ((value is False or value is None)
                 and operator in ('=', '!=')):
-            return (column == Null) == value
+            return column != Null
         elif operator == 'not like':
             return column.like(value)
         elif operator == 'not ilike':
