@@ -11,17 +11,18 @@ import ConfigParser
 from glob import iglob
 
 from sql import Table
-from sql.functions import Now
+from sql.functions import CurrentTimestamp
 
 import trytond.tools as tools
 from trytond.config import config
 from trytond.transaction import Transaction
 from trytond.cache import Cache
+from trytond import backend
 import trytond.convert as convert
 
 logger = logging.getLogger(__name__)
 
-ir_module = Table('ir_module_module')
+ir_module = Table('ir_module')
 ir_model_data = Table('ir_model_data')
 
 OPJ = os.path.join
@@ -248,8 +249,10 @@ def load_module_graph(graph, pool, update=None, lang=None):
 
             modules_todo.append((module, list(tryton_parser.to_delete)))
 
-            for filename in iglob('%s/%s/*.po'
-                    % (package.info['directory'], 'locale')):
+            localedir = '%s/%s' % (package.info['directory'], 'locale')
+            for filename in itertools.chain(
+                    iglob('%s/*.po' % localedir),
+                    iglob('%s/override/*.po' % localedir)):
                 filename = filename.replace('/', os.sep)
                 lang2 = os.path.splitext(os.path.basename(filename))[0]
                 if lang2 not in lang:
@@ -271,7 +274,7 @@ def load_module_graph(graph, pool, update=None, lang=None):
                 cursor.execute(*ir_module.insert(
                         [ir_module.create_uid, ir_module.create_date,
                             ir_module.name, ir_module.state],
-                        [[0, Now(), package.name, 'installed']]))
+                        [[0, CurrentTimestamp(), package.name, 'installed']]))
             module2state[package.name] = 'installed'
 
         cursor.commit()
@@ -366,7 +369,14 @@ def load_modules(database_name, pool, update=None, lang=None):
 
     def _load_modules():
         global res
+        TableHandler = backend.get('TableHandler')
         cursor = Transaction().cursor
+
+        # Migration from 3.6: remove double module
+        old_table = 'ir_module_module'
+        new_table = 'ir_module'
+        if TableHandler.table_exist(cursor, old_table):
+            TableHandler.table_rename(cursor, old_table, new_table)
         if update:
             cursor.execute(*ir_module.select(ir_module.name,
                     where=ir_module.state.in_(('installed', 'to install',
@@ -407,7 +417,7 @@ def load_modules(database_name, pool, update=None, lang=None):
                 cursor.commit()
                 res = False
 
-            Module = pool.get('ir.module.module')
+            Module = pool.get('ir.module')
             Module.update_list()
         cursor.commit()
         Cache.resets(database_name)
