@@ -22,7 +22,7 @@ logger = logging.getLogger(__name__)
 
 ir_configuration = Table('ir_configuration')
 ir_lang = Table('ir_lang')
-ir_module = Table('ir_module_module')
+ir_module = Table('ir_module')
 res_user = Table('res_user')
 
 
@@ -65,9 +65,13 @@ def dispatch(host, port, protocol, database_name, user, session, object_type,
                 ('es_EC', 'Español (Ecuador)'),
                 ('es_ES', 'Español (España)'),
                 ('es_CO', 'Español (Colombia)'),
+                ('es_MX', 'Español (México)'),
                 ('fr_FR', 'Français'),
+                ('hu_HU', 'Magyar'),
+                ('it_IT', 'Italiano'),
                 ('lt_LT', 'Lietuvių'),
                 ('nl_NL', 'Nederlands'),
+                ('pt_BR', 'Português (Brasil)'),
                 ('ru_RU', 'Russian'),
                 ('sl_SI', 'Slovenščina'),
             ]
@@ -237,7 +241,7 @@ def create(database_name, password, lang, admin_password):
             User.write([admin], {
                     'password': admin_password,
                     })
-            Module = pool.get('ir.module.module')
+            Module = pool.get('ir.module')
             if Module:
                 Module.update_list()
             transaction.cursor.commit()
