@@ -21,7 +21,7 @@ try:
 except ImportError:
     bcrypt = None
 
-from ..model import ModelView, ModelSQL, fields
+from ..model import ModelView, ModelSQL, fields, Unique
 from ..wizard import Wizard, StateView, Button, StateTransition
 from ..tools import grouped_slice
 from .. import backend
@@ -81,8 +81,9 @@ class User(ModelSQL, ModelView):
                 'set_preferences': RPC(readonly=False, check_access=False),
                 'get_preferences_fields_view': RPC(check_access=False),
                 })
+        table = cls.__table__()
         cls._sql_constraints += [
-            ('login_key', 'UNIQUE (login)',
+            ('login_key', Unique(table, table.login),
                 'You can not have two users with the same login!')
         ]
         cls._preferences_fields = [
@@ -102,12 +103,11 @@ class User(ModelSQL, ModelView):
             'groups',
         ]
         cls._error_messages.update({
-            'rm_root': ('You can not remove the root user\n'
-                    'as it is used internally for resources\n'
-                    'created by the system '
-                    '(updates, module installation, ...)'),
-            'wrong_password': 'Wrong password!',
-            })
+                'delete_forbidden': ('Users can not be deleted '
+                    'for logging purpose.\n'
+                    'Instead you must inactivate them.'),
+                'wrong_password': 'Wrong password!',
+                })
 
     @classmethod
     def __register__(cls, module_name):
@@ -266,11 +266,7 @@ class User(ModelSQL, ModelView):
 
     @classmethod
     def delete(cls, users):
-        if [u.id for u in users if u.id == 0]:
-            cls.raise_user_error('rm_root')
-        super(User, cls).delete(users)
-        # Restart the cache for _get_login
-        cls._get_login_cache.clear()
+        cls.raise_user_error('delete_forbidden')
 
     @classmethod
     def search_rec_name(cls, name, clause):
@@ -303,7 +299,7 @@ class User(ModelSQL, ModelView):
         pool = Pool()
         ModelData = pool.get('ir.model.data')
         Action = pool.get('ir.action')
-        ConfigItem = pool.get('ir.module.module.config_wizard.item')
+        ConfigItem = pool.get('ir.module.config_wizard.item')
 
         res = {}
         if context_only:
@@ -457,7 +453,7 @@ class User(ModelSQL, ModelView):
         cursor = Transaction().cursor
         table = cls.__table__()
         cursor.execute(*table.select(table.id, table.password_hash,
-                where=(table.login == login) & table.active))
+                where=(table.login == login) & (table.active == True)))
         result = cursor.fetchone() or (None, None)
         cls._get_login_cache.set(login, result)
         return result
