@@ -2,6 +2,7 @@
 # this repository contains the full copyright notices and license terms.
 "Test for Tree"
 from sql import Null
+from sql.conditionals import Case
 
 from trytond.model import ModelView, ModelSQL, fields
 
@@ -29,7 +30,7 @@ class MPTT(ModelSQL, ModelView):
     @staticmethod
     def order_sequence(tables):
         table, _ = tables[None]
-        return [table.sequence == Null, table.sequence]
+        return [Case((table.sequence == Null, 0), else_=1), table.sequence]
 
     @staticmethod
     def default_active():
