@@ -1,6 +1,6 @@
 #!/usr/bin/env python
-#This file is part of Tryton.  The COPYRIGHT file at the top level of
-#this repository contains the full copyright notices and license terms.
+# This file is part of Tryton.  The COPYRIGHT file at the top level of
+# this repository contains the full copyright notices and license terms.
 import logging
 import argparse
 import os
@@ -20,6 +20,8 @@ parser.add_argument("-c", "--config", dest="config",
     help="specify config file")
 parser.add_argument("-m", "--modules", action="store_true", dest="modules",
     default=False, help="Run also modules tests")
+parser.add_argument("--no-doctest", action="store_false", dest="doctest",
+    default=True, help="Don't run doctest")
 parser.add_argument("-v", action="count", default=0, dest="verbosity",
     help="Increase verbosity")
 parser.add_argument('tests', metavar='test', nargs='*')
@@ -39,6 +41,6 @@ from trytond.tests.test_tryton import all_suite, modules_suite
 if not opt.modules:
     suite = all_suite(opt.tests)
 else:
-    suite = modules_suite(opt.tests)
+    suite = modules_suite(opt.tests, doc=opt.doctest)
 result = unittest.TextTestRunner(verbosity=opt.verbosity).run(suite)
 sys.exit(not result.wasSuccessful())
