@@ -1,14 +1,15 @@
 # -*- coding: utf-8 -*-
-#This file is part of Tryton.  The COPYRIGHT file at the top level of
-#this repository contains the full copyright notices and license terms.
+# This file is part of Tryton.  The COPYRIGHT file at the top level of
+# this repository contains the full copyright notices and license terms.
 
 import unittest
+import doctest
 import datetime
 import sql
 import sql.operators
 
-from trytond.tools import reduce_ids, safe_eval, datetime_strftime, \
-    reduce_domain
+from trytond.tools import reduce_ids, datetime_strftime, \
+    reduce_domain, decimal_, is_instance_method
 
 
 class ToolsTestCase(unittest.TestCase):
@@ -58,24 +59,6 @@ class ToolsTestCase(unittest.TestCase):
                 | (self.table.id.in_([15.0, 18.0, 19.0, 21.0]))))
         self.assertRaises(AssertionError, reduce_ids, self.table.id, [1.1])
 
-    def test0060safe_eval_builtin(self):
-        'Attempt to access a unsafe builtin'
-        self.assertRaises(NameError, safe_eval, "open('test.txt', 'w')")
-
-    def test0061safe_eval_getattr(self):
-        'Attempt to get arround direct attr access'
-        self.assertRaises(NameError, safe_eval, "getattr(int, 'real')")
-
-    def test0062safe_eval_func_globals(self):
-        'Attempt to access global enviroment where fun was defined'
-        self.assertRaises(SyntaxError, safe_eval,
-                "def x(): pass; print x.func_globals")
-
-    def test0063safe_eval_lowlevel(self):
-        "Lowlevel tricks to access 'object'"
-        self.assertRaises(ValueError, safe_eval,
-                "().__class__.mro()[1].__subclasses__()")
-
     def test0070datetime_strftime(self):
         'Test datetime_strftime'
         self.assert_(datetime_strftime(datetime.date(2005, 3, 2),
@@ -111,10 +94,31 @@ class ToolsTestCase(unittest.TestCase):
             self.assertEqual(reduce_domain(i), j,
                     '%s -> %s != %s' % (i, reduce_domain(i), j))
 
+    def test_is_instance_method(self):
+        'Test is_instance_method'
+
+        class Foo(object):
+
+            @staticmethod
+            def static():
+                pass
+
+            @classmethod
+            def klass(cls):
+                pass
+
+            def instance(self):
+                pass
+
+        self.assertFalse(is_instance_method(Foo, 'static'))
+        self.assertFalse(is_instance_method(Foo, 'klass'))
+        self.assertTrue(is_instance_method(Foo, 'instance'))
+
 
 def suite():
     func = unittest.TestLoader().loadTestsFromTestCase
     suite = unittest.TestSuite()
     for testcase in (ToolsTestCase,):
         suite.addTests(func(testcase))
+    suite.addTest(doctest.DocTestSuite(decimal_))
     return suite
