@@ -9,7 +9,7 @@ from itertools import chain
 import operator
 from lxml import etree
 
-from trytond.pool import Pool
+from trytond.pool import Pool, isregisteredby
 from trytond import backend
 from trytond.model import Workflow
 from trytond.model.fields import get_eval_fields
@@ -41,7 +41,7 @@ def install_module(name):
     create_db()
     with Transaction().start(DB_NAME, USER,
             context=CONTEXT) as transaction:
-        Module = POOL.get('ir.module.module')
+        Module = POOL.get('ir.module')
 
         modules = Module.search([
                 ('name', '=', name),
@@ -59,7 +59,7 @@ def install_module(name):
         Module.install(modules)
         transaction.cursor.commit()
 
-        InstallUpgrade = POOL.get('ir.module.module.install_upgrade',
+        InstallUpgrade = POOL.get('ir.module.install_upgrade',
             type='wizard')
         instance_id, _, _ = InstallUpgrade.create()
         transaction.cursor.commit()
@@ -78,9 +78,7 @@ class ModuleTestCase(unittest.TestCase):
     def test_rec_name(self):
         with Transaction().start(DB_NAME, USER, context=CONTEXT):
             for mname, model in Pool().iterobject():
-                # Don't test model not registered by the module
-                if not any(issubclass(model, cls) for cls in
-                        Pool().classes['model'].get(self.module, [])):
+                if not isregisteredby(model, self.module):
                     continue
                 # Skip testing default value even if the field doesn't exist
                 # as there is a fallback to id
@@ -100,12 +98,19 @@ class ModuleTestCase(unittest.TestCase):
                     ('model', '!=', ''),
                     ])
             for view in views:
-                view_id = view.inherit and view.inherit.id or view.id
+                if view.inherit and view.inherit.model == view.model:
+                    view_id = view.inherit.id
+                else:
+                    view_id = view.id
                 model = view.model
                 Model = POOL.get(model)
                 res = Model.fields_view_get(view_id)
                 assert res['model'] == model
                 tree = etree.fromstring(res['arch'])
+
+                validator = etree.RelaxNG(etree=View.get_rng(res['type']))
+                validator.assert_(tree)
+
                 tree_root = tree.getroottree().getroot()
 
                 for element in tree_root.iter():
@@ -121,9 +126,7 @@ class ModuleTestCase(unittest.TestCase):
         'Test for missing depends'
         with Transaction().start(DB_NAME, USER, context=CONTEXT):
             for mname, model in Pool().iterobject():
-                # Don't test model not registered by the module
-                if not any(issubclass(model, cls) for cls in
-                        Pool().classes['model'].get(self.module, [])):
+                if not isregisteredby(model, self.module):
                     continue
                 for fname, field in model._fields.iteritems():
                     fields = set()
@@ -143,6 +146,35 @@ class ModuleTestCase(unittest.TestCase):
                         'Unknown depends %s in "%s"."%s"' % (
                             list(depends - set(model._fields)), mname, fname))
 
+    def test_field_methods(self):
+        'Test field methods'
+        with Transaction().start(DB_NAME, USER, context=CONTEXT):
+            for mname, model in Pool().iterobject():
+                if not isregisteredby(model, self.module):
+                    continue
+                for attr in dir(model):
+                    for prefixes in [['default_'],
+                            ['on_change_', 'on_change_with_'],
+                            ['order_'], ['domain_'], ['autocomplete_']]:
+                        if attr == 'on_change_with':
+                            continue
+                        # TODO those method should be renamed
+                        if attr == 'default_get':
+                            continue
+                        if mname == 'ir.rule' and attr == 'domain_get':
+                            continue
+
+                        # Skip if it is a field
+                        if attr in model._fields:
+                            continue
+                        fnames = [attr[len(prefix):] for prefix in prefixes
+                            if attr.startswith(prefix)]
+                        if not fnames:
+                            continue
+                        assert any(f in model._fields for f in fnames), (
+                            'Field method "%s"."%s" for unknown field' % (
+                                mname, attr))
+
     def test_menu_action(self):
         'Test that menu actions are accessible to menu\'s group'
         with Transaction().start(DB_NAME, USER, context=CONTEXT):
@@ -192,9 +224,7 @@ class ModuleTestCase(unittest.TestCase):
         'Test all workflow transitions exist'
         with Transaction().start(DB_NAME, USER, context=CONTEXT):
             for mname, model in Pool().iterobject():
-                # Don't test model not registered by the module
-                if not any(issubclass(model, cls) for cls in
-                        Pool().classes['model'].get(self.module, [])):
+                if not isregisteredby(model, self.module):
                     continue
                 if not issubclass(model, Workflow):
                     continue
